@@ -104,11 +104,15 @@ tar_combine_impl <- function(
   assert_chr(name)
   assert_targets(targets)
   names_chr <- map_chr(targets, ~.x$settings$name)
-  names_sym <- rlang::syms(names_chr)
+  names_sym <- as_symbols(names_chr)
   if (use_names) {
     names(names_sym) <- names_chr
   }
-  command <- tidy_eval(command, envir = list(.x = names_sym), tidy_eval = TRUE)
+  command <- tar_tidy_eval(
+    command,
+    envir = list(.x = names_sym),
+    tidy_eval = TRUE
+  )
   tar_target_raw(
     name = name,
     command = command,
