@@ -105,7 +105,7 @@ tar_files_input_raw <- function(
     retrieval = "main",
     cue = cue
   )
-  name_files_sym <- rlang::sym(name_files)
+  name_files_sym <- as.symbol(name_files)
   downstream <- tar_target_raw(
     name = name,
     command = as.expression(name_files_sym),
