@@ -31,8 +31,16 @@ tar_format <- function(format) {
   body(out) <- substitute({
     name <- deparse_language(substitute(name))
     envir <- tar_option_get("envir")
-    command <- tidy_eval(as.expression(substitute(command)), envir, tidy_eval)
-    pattern <- tidy_eval(as.expression(substitute(pattern)), envir, tidy_eval)
+    command <- tar_tidy_eval(
+      as.expression(substitute(command)),
+      envir,
+      tidy_eval
+    )
+    pattern <- tar_tidy_eval(
+      as.expression(substitute(pattern)),
+      envir,
+      tidy_eval
+    )
     targets::tar_target_raw(
       name = name,
       command = command,
