@@ -90,7 +90,11 @@ tar_knit <- function(
   assert_chr(path, "path argument of tar_knit() must be a character.")
   assert_path(path, paste("the path", path, "for tar_knit() does not exist"))
   envir <- tar_option_get("envir")
-  args <- tidy_eval(substitute(list(...)), envir = envir, tidy_eval = tidy_eval)
+  args <- tar_tidy_eval(
+    substitute(list(...)),
+    envir = envir,
+    tidy_eval = tidy_eval
+  )
   tar_target_raw(
     name = deparse_language(substitute(name)),
     command = tar_knit_command(path, args, quiet),
@@ -109,7 +113,7 @@ tar_knit <- function(
 tar_knit_command <- function(path, args, quiet) {
   args$input <- path
   args$quiet <- quiet
-  deps <- call_list(rlang::syms(knitr_deps(path)))
+  deps <- call_list(as_symbols(knitr_deps(path)))
   fun <- call_ns("tarchetypes", "tar_knit_run")
   exprs <- list(fun, path = path, args = args, deps = deps)
   as.expression(as.call(exprs))
@@ -130,11 +134,12 @@ tar_knit_command <- function(path, args, quiet) {
 #'   report, automatically created by `tar_knit()`.
 tar_knit_run <- function(path, args, deps) {
   assert_package("knitr")
+  withr::local_options(list(crayon.enabled = NULL))
   opt <- knitr::opts_knit$get("root.dir")
   knitr::opts_knit$set(root.dir = getwd())
   on.exit(knitr::opts_knit$set(root.dir = opt))
   envir <- parent.frame()
-  args$envir <- args$envir %||% targets::tar_envir(default = envir)
+  args$envir <- args$envir %|||% targets::tar_envir(default = envir)
   force(args$envir)
   fs::path_rel(c(do.call(knitr::knit, args), path))
 }
